@@ -3,7 +3,7 @@ package Log::Dispatch::Screen;
 use strict;
 use warnings;
 
-our $VERSION = '2.48';
+our $VERSION = '2.49';
 
 use Log::Dispatch::Output;
 
@@ -32,6 +32,7 @@ sub new {
 
     my $fh = IO::Handle->new;
     $fh->fdopen( $p{stderr} ? fileno(*STDERR) : fileno(*STDOUT), 'w' );
+    $fh->autoflush(1);
     binmode $fh, ':encoding(UTF-8)' if $p{utf8};
 
     my $self = bless { fh => $fh }, $class;
@@ -61,7 +62,7 @@ Log::Dispatch::Screen - Object for logging to the screen
 
 =head1 VERSION
 
-version 2.48
+version 2.49
 
 =head1 SYNOPSIS
 
@@ -83,11 +84,14 @@ version 2.48
 =head1 DESCRIPTION
 
 This module provides an object for logging to the screen (really
-STDOUT or STDERR).
+C<STDOUT> or C<STDERR>).
 
 Note that a newline will I<not> be added automatically at the end of a
 message by default. To do that, pass C<< newline => 1 >>.
 
+The handle will be autoflushed, but this module opens it's own handle to fd 1
+or 2 instead of using the global C<STDOUT> or C<STDERR>.
+
 =for Pod::Coverage new log_message
 
 =head1 CONSTRUCTOR
